#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
Convenience wrapper for running randopass directly from source tree.
""" 
 
from randopass.randopass import main
 
if __name__ == '__main__':
    main()